#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Unixutils
version:              1.54.1
visibility:           public
id:                   Unixutils-1.54.1-1kwUydwj41ECOaaNXPJmzw
key:                  Unixutils-1.54.1-1kwUydwj41ECOaaNXPJmzw
license:              BSD-3-Clause
maintainer:           jeremy@n-heptane.com
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  e3b213c53b829ed0f1b247734ece48db
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-8.10.5/site-local/Unixutils-1.54.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/Unixutils-1.54.1
hs-libraries:         HSUnixutils-1.54.1-1kwUydwj41ECOaaNXPJmzw
extra-libraries:      crypt
depends:
    base-4.14.2.0 bytestring-0.10.12.0 directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1 mtl-2.2.2 process-1.6.9.0
    process-extras-0.7.4-CKJqOJCm6OP1UfTzItmPPw
    pureMD5-2.1.3-3d85SCd5b2Q1zbasIMLvI7
    regex-tdfa-1.3.1.1-GKHvEQcFLVkJ8X6kzhWyIo unix-2.7.2.2
    zlib-0.6.2.3-GAUO2iiPelTDtuicMOd1b8

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

